@@ -1,7 +1,7 @@
 import os
 from logging import getLogger
 
-from .code import get_ga_client_id, check_tiledesk_api
+from .code import get_ga_client_id, check_tiledesk_api, close_converstaion
 
 logger = getLogger(__name__)
 
